
require(divDyn) # to prepare and analyze PBDB data and create figures
require(dplyr)  # for affinites

## load data
setwd("...")
all2 <- read.csv(file="Data_LPIA.csv", sep=",", header=T, skipNul = TRUE )

## prepare data
excl <- which(duplicated(all2$occurrence_no)) # find duplicates
all2 <- all2[-excl,] # remove duplicates
nrow(all2) # total number of occurrences
all2 <- all2[all2$genus!="", ]  # remove non-informative genus names
all2 <- subset(all2, accepted_rank=="species" | accepted_rank=="genus") # limit to entries with at least genus rank
nrow(all2) # number of occurrences with genus information
all2$clgen <- paste(all2$class, all2$genus)  # in case there are homonymies, add class name to genus name in new column "clgen"

## stratigraphic binning
data(stages) # load stages object from divDyn
data(keys)  # load keys object from divDyn #contains information to group occurrences based on environmental and lithological variables
stgMin <- categorize(all2[ ,"early_interval"], keys$stgInt) # categorize entries by stages according to keys object (using stage numbers)
stgMax <- categorize(all2[ ,"late_interval"], keys$stgInt) # categorize entries by stages according to keys object (using stage numbers)
stgMin <- as.numeric(stgMin) # convert stage numbers  to numeric
stgMax <- as.numeric(stgMax) # convert stage numbers  to numeric
all2$stg <- rep(NA, nrow(all2)) # create empty vector
# condition is expressed indicating which rows have only single assigned stage number:
# select entries, where
stgCondition <- c(
  # the early and late interval fields indicate the same stg
  which(stgMax==stgMin),
  # or the late_interval field is empty
  which(stgMax==-1))
# those values are copied for which the condition is true
all2$stg[stgCondition] <- stgMin[stgCondition] # in these entries, use the stg indicated by the early_interval

##stats for table 1
#create function to count number of genera
genera <- function(x){length(unique(x$clgen))}
genera(all2) # total number of genera
table(all2$phylum) # number of occurrences brachipods, molluscs
table(all2$class) # number of occurrences bivalves, gastropods, classes of brachipods
genera(subset(all2, all2$class=="Bivalvia")) # number of genera bivalves
genera(subset(all2, all2$class=="Gastropoda")) # number of genera gastropods
genera(subset(all2, all2$phylum=="Brachiopoda")) # number of genera brachiopods

# subset dataset to entries with stage level information
all <- all2[!is.na(all2$stg), ]  #remove entries without stage

# subset dataset with stage level info by taxa
biv <- subset(all, all$class=="Bivalvia") # bivalves
gast <- subset(all, all$class=="Gastropoda") # gastropods
brachs <- subset(all, all$phylum=="Brachiopoda") # brachiopods

##stats for table 1
genera(gast) # number of genera gastropods
genera(biv) # number of genera bivalves
genera(brachs) # number of genera brachiopods
#subsets brachiopods
genera(subset(all, all$class=="Chileata")) # number of genera Chileata
genera(subset(all, all$class=="Craniata"))  # number of genera Craniata
genera(subset(all, all$class=="Lingulata")) # number of genera Lingulata
genera(subset(all, all$class=="Rhynchonellata")) # number of genera Rhynchonellata
genera(subset(all, all$class=="Strophomenata")) # number of genera Strophomenata

### stats
## return number of occurrences, collections, richness and other diversity metrics in each bin per taxon
# entire dataset
Sall <- binstat(all, tax="clgen", bin="stg", coll="collection_no", ref="reference_no", duplicates=F, indices = T, noNAStart=F)
#gastropods
Sgast <- binstat(gast, tax="clgen", bin="stg", coll="collection_no", ref="reference_no", duplicates=F, indices = T, noNAStart=F)
#bivalves
Sbiv <- binstat(biv, tax="clgen", bin="stg", coll="collection_no", ref="reference_no", duplicates=F, indices = T, noNAStart=F)
#brachiopods
Sbrachs <- binstat(brachs, tax="clgen", bin="stg", coll="collection_no", ref="reference_no", duplicates=F, indices = T, noNAStart=F)


##subsampling using SQS, quorum = 0.60, 500 iterations
# entire dataset
sqs0.6 <-subsample(all, iter=500, q=0.6, tax="clgen", bin="stg", type="sqs", noNAStart=TRUE, singleton=F)
#gastropods
sqs0.6.g <-subsample(gast, iter=500, q=0.6, tax="clgen", bin="stg", type="sqs", noNAStart=TRUE, singleton=F)
#bivalves
sqs0.6.bi <-subsample(biv, iter=500, q=0.6, tax="clgen", bin="stg", type="sqs", noNAStart=TRUE, singleton=F)
#brachiopods
sqs0.6.br <-subsample(brachs, iter=500, q=0.6, tax="clgen", bin="stg", type="sqs", noNAStart=TRUE, singleton=F)

##correlation test between subsampled genus richness and number of occurrences
cor.test(sqs0.6$divCSIB, Sall$occs[35:50], method="spearman")

#plot SQS genus richness (CSIB) ##figure 1 (temperate curve was added manually)
cols <- c("darkgreen", "blue", "orange","black")
plotnames <-c("gastropods", "bivalves", "brachiopods","all")
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylab="SQS genus richness (CSIB)", ylim=c(0,300))
lines(stages$mid[35:50], sqs0.6$divCSIB, col=cols[4], lwd=2) #all
lines(stages$mid[35:50], sqs0.6.g$divCSIB, lty=3, lwd=2, col=cols[1]) #gastropods
lines(stages$mid[35:50], sqs0.6.bi$divCSIB, lty=2, lwd=2, col=cols[2]) #bivalves
lines(stages$mid[35:50], sqs0.6.br$divCSIB, lty=4, lwd=2, col=cols[3]) #brachiopods
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames, col=cols, lty=c(3,2,4,1), lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

###
#plot occurrences ##appendix 6A
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylim=c(0,10000),
       ylab="number of occurrences")
lines(stages$mid[35:50], Sall$occs[35:50], lwd=2, col=cols[4]) #all
lines(stages$mid[35:50], Sgast$occs[35:50], lty=3, lwd=2, col=cols[1]) #gastropods
lines(stages$mid[35:50], Sbiv$occs[35:50], lty=2, lwd=2, col=cols[2]) #bivalves
lines(stages$mid[35:50], Sbrachs$occs[35:50], lty=4, lwd=2, col=cols[3]) #brachiopods
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames, col=cols,lty=c(3,2,4,1), lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

##analyzing taxonomic rates
##use divDyn function to calculate metrics for datasets
#entire dataset
dd <- divDyn(all, bin="stg", tax="clgen")
# gastropods
dd_g<- divDyn(gast, bin="stg", tax="clgen")
# bivalves
dd_bi<- divDyn(biv, bin="stg", tax="clgen")
# brachiopods
dd_br<- divDyn(brachs, bin="stg", tax="clgen")

# return origination rates from datasets
ori <- dd[ , "oriPC"] # origination rates entire dataset
ori_g <- dd_g[ , "oriPC"] # origination rates gastropods
ori_bi <- dd_bi[ , "oriPC"] # origination rates bivalves
ori_br <- dd_br[ , "oriPC"] # origination rates brachiopods

age <- stages[ , "mid"] # time interval midpoints

#plot origination rates by taxon ##appendix 6B
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylim=c(0, 1.3), ylab="origination rate")
lines(age[35:50], ori[35:50], col=cols[4], lwd=2) #all
lines(age[35:50], ori_g[35:50], col=cols[1], lty=3, lwd=2) #gastropods
lines(age[35:50], ori_bi[35:50], col=cols[2], lty=2, lwd=2) #bivalves
lines(age[35:50], ori_br[35:50], col=cols[3],lty=4, lwd=2) #brachiopods
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames, col=cols,lty=c(3,2,4,1), lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

# return extinction rates from datasets
ext <- dd[ , "extPC"] # extinction rates entire dataset
ext_g <- dd_g[ , "extPC"] # extinction rates gastropods
ext_bi <- dd_bi[ , "extPC"] # extinction rates bivalves
ext_br <- dd_br[ , "extPC"] # extinction rates brachiopods

#plot extinction rates by taxon ##appendix 6C
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylim=c(0, 1.3), ylab="extinction rate")
lines(age[35:50], ext[35:50], col=cols[4], lwd=2) #all
lines(age[35:50], ext_g[35:50], col=cols[1], lty=3, lwd=2) #gastropods
lines(age[35:50], ext_bi[35:50], col=cols[2], lty=2, lwd=2) #bivalves
lines(age[35:50], ext_br[35:50], col=cols[3], lty=4, lwd=2) #brachiopods
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames, col=cols, lty=c(3,2,4,1), lwd=c(2,2), bg="white", inset=c(0.01, 0.01))


######## environments

## create new list for lithology  (see appendix 2):
# create vector with entries for carbonate
carb <-as.vector(c( "bafflestone",  "bindstone", "dolomite","framestone", 
                    "carbonate", "grainstone",  "lime mudstone" , "packstone", 
                    "reef rocks", "limestone","rudstone" ,  "floatstone" ,
                    "wackestone","limestone", "marl","mudstone-carb","mudstone-carb (?)"))
# create vector with entries for siliciclastics
sil <- as.vector(c("shale","shale?" ,"claystone",  "mud-siltstone",
                   "sandstone","siliciclastic","siliciclastica","siltstone",
                   "mudstone","mudstone-clast","mudstone-clast (?)") )
# create vector for entries not used for analyses
excl <- as.vector(c("breccia","chert","cherty/siliceous", "coal" ,"conglomerate",
                    "gravel","ironstone ", "mixed carbonate-siliciclastic",
                    "not reported","phosphorite","quartzite", "sediments",
                    "slate","tuff")) 
def <- as.vector("unknown")

# add own categories to keys object
lith_new <- list(carbonate=carb, siliciclastics=sil, exclude=excl, default=def) # create list of variables
keys$lith2 <- lith_new # add to keys object

## categorize & calculate affinities # lithology2
all$lith2 <- categorize(all$lithology1, keys$lith2) # categorize lithology into assigned groups
all_l <- subset(all, all$lith2  %in% c("carbonate","siliciclastics")) # first subset dataset to remove "excl" values
aff_lith <- affinity(all_l, bin="stg", tax="clgen", method="binom", env="lith2", alpha=0.5) # function 'affinity' returns preferred environment of each taxon
# add affinities to dataset
aff_lith <- as.data.frame(aff_lith)
aff_lith[,2] <- rownames(aff_lith)
colnames(aff_lith) <- c("lith_aff","clgen") # create column names
L <- left_join(all_l, aff_lith, by="clgen") # join occurrence dataset with affinity dataframe
L2 <- subset(L, !(is.na(L$lith_aff))) # reduce to genera with affinities

## return number of occurrences, collections, richness and other diversity metrics in each stage 
# only genera with lithology affinity
S_L <- binstat(L2, tax="clgen", bin="stg", coll="collection_no", ref="reference_no", duplicates=F, indices = T, noNAStart=F)
# only carbonates
carb <- subset(L, L$lith_aff=="carbonate") # subset L to carbonates
samp_carb <-binstat(carb, tax="clgen", bin="stg", coll="collection_no", ref="reference_no", duplicates=F, indices = T, noNAStart=F)
# only siliciclastics
sil <- subset(L, L$lith_aff=="siliciclastics") # subset L to siliciclastics
samp_sil <-binstat(sil, tax="clgen", bin="stg", coll="collection_no", ref="reference_no", duplicates=F, indices = T, noNAStart=F)

## categorize & calculate affinities # bathymetry
all$bath <- categorize(all$environment, keys$bath) #water depth
all_b <- all[all$bath!="unknown",] ##remove unknown entries
aff_bath <- affinity(all_b, bin="stg", tax="clgen", method="binom", env="bath", alpha=0.5)
# add affinities to dataset
aff_bath <- as.data.frame(aff_bath)
aff_bath[,2] <- rownames(aff_bath)
colnames(aff_bath) <- c("bath_aff","clgen")
B <- left_join(all_b, aff_bath, by="clgen")

## return number of occurrences, collections, richness and other diversity metrics in each stage
#deep
deep <- subset(B, B$bath_aff=="deep")
samp_deep <-binstat(deep, tax="clgen", bin="stg", coll="collection_no", ref="reference_no", duplicates=F, indices = T, noNAStart=F)
#shallow
shal <- subset(B, B$bath_aff=="shallow")
samp_shal <-binstat(shal, tax="clgen", bin="stg", coll="collection_no", ref="reference_no", duplicates=F, indices = T, noNAStart=F)

## categorize & calculate affinities # grain size
all$gra <- categorize(all$lithology1, keys$grain)
all_g <- all[all$gra!="unknown",] ##remove unknown entries
aff_gra <- affinity(all_g, bin="stg", tax="clgen", method="binom", env="gra", alpha=0.5)
# add affinities to dataset
aff_gra <- as.data.frame(aff_gra)
aff_gra[,2] <- rownames(aff_gra)
colnames(aff_gra) <- c("gra_aff","clgen")
G <- left_join(all_g, aff_gra, by="clgen")

## return number of occurrences, collections, richness and other diversity metrics in each stage
#coarse
co <- subset(G, G$gra_aff=="coarse")
samp_co <-binstat(co, tax="clgen", bin="stg", coll="collection_no", ref="reference_no", duplicates=F, indices = T, noNAStart=F)
#fine
fine <- subset(G, G$gra_aff=="fine")
samp_fine <-binstat(fine, tax="clgen", bin="stg", coll="collection_no", ref="reference_no", duplicates=F, indices = T, noNAStart=F)

## categorize & calculate affinities # reef vs non-reef
all$reef <- categorize(all$environment, keys$reef) #environment type
all$reef[all$lith=="clastic" & all$environment=="marine indet."] <- "non-reef"   #reef
all_r <- all[all$reef!="unknown",]
aff_reef <- affinity(all_r, bin="stg", tax="clgen", method="binom", env="reef", alpha=0.5)
# add affinities to dataset
aff_reef <- as.data.frame(aff_reef)
aff_reef[,2] <- rownames(aff_reef)
colnames(aff_reef) <- c("reef_aff","clgen")
R <- left_join(all_r, aff_reef, by="clgen")

## return number of occurrences, collections, richness and other diversity metrics in each stage
#reef
re <- subset(R, R$reef_aff=="reef")
samp_re <-binstat(re, tax="clgen", bin="stg", coll="collection_no", ref="reference_no", duplicates=F, indices = T, noNAStart=F)
#non-reef
nr <- subset(R, R$reef_aff=="non-reef")
samp_nr <-binstat(nr, tax="clgen", bin="stg", coll="collection_no", ref="reference_no", duplicates=F, indices = T, noNAStart=F)

########
## divide subsetted environment datasets into taxa #CARBONATES
carb_g <- subset(carb, carb$class=="Gastropoda") # gastropods
carb_bi <- subset(carb, carb$class=="Bivalvia") # bivalves
carb_br <- subset(carb, carb$phylum=="Brachiopoda") # brachiopods
## stats
dd_carb <-divDyn(carb, tax="clgen", bin="stg") # entire carbonate dataset
dd_carb_g <-divDyn(carb_g, tax="clgen", bin="stg") # gastropods
dd_carb_bi <-divDyn(carb_bi, tax="clgen", bin="stg") # bivalves
dd_carb_br <-divDyn(carb_br, tax="clgen", bin="stg") # brachiopods

##plot genus richness of carbonate dataset # appendix 7A
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylab="genus richness (CSIB)", ylim=c(0,250))
lines(stages$mid[35:50], dd_carb$divCSIB[35:50], col=cols[4], lwd=2) #all
lines(stages$mid[35:50], dd_carb_g$divCSIB[35:50], lty=3, lwd=2, col=cols[1]) #gastropods
lines(stages$mid[35:50], dd_carb_bi$divCSIB[35:50], lty=2, lwd=2, col=cols[2]) #bivalves
lines(stages$mid[35:50], dd_carb_br$divCSIB[35:50], lty=4, lwd=2, col=cols[3]) #brachiopods
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames, col=cols, lty=c(3,2,4,1), lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

## divide subsetted environment datasets into taxa #SILICICLASTICS
sil_g <- subset(sil, sil$class=="Gastropoda") # gastropods
sil_bi <- subset(sil, sil$class=="Bivalvia") # bivalves
sil_br <- subset(sil, sil$phylum=="Brachiopoda") # brachiopods
## stats
dd_sil <-divDyn(sil, tax="clgen", bin="stg") # entire siliciclastics dataset
dd_sil_g <-divDyn(sil_g, tax="clgen", bin="stg") # gastropods
dd_sil_bi <-divDyn(sil_bi, tax="clgen", bin="stg") # bivalves
dd_sil_br <-divDyn(sil_br, tax="clgen", bin="stg") # brachiopods

##plot genus richness of siliciclastics dataset # appendix 7C
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylab="genus richness (CSIB)", ylim=c(0,250))
lines(stages$mid[35:50], dd_sil$divCSIB[35:50], col=cols[4], lwd=2) #all
lines(stages$mid[35:50], dd_sil_g$divCSIB[35:50], lty=3, lwd=2, col=cols[1]) #gastropods
lines(stages$mid[35:50], dd_sil_bi$divCSIB[35:50], lty=2, lwd=2, col=cols[2]) #bivalves
lines(stages$mid[35:50], dd_sil_br$divCSIB[35:50], lty=4, lwd=2, col=cols[3]) #brachiopods
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames, col=cols, lty=c(3,2,4,1), lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

##stats for table 1
# number of genera
genera(carb) # all carbonates
genera(carb_g) # carbonates # gastropods
genera(carb_bi) # carbonates # bivalves
genera(carb_br) # carbonates # brachiopods
genera(sil) # all siliciclastics
genera(sil_g) # siliciclastics # gastropods
genera(sil_bi) # siliciclastics # bivalves
genera(sil_br) # siliciclastics # brachiopods

## divide subsetted environment datasets into taxa #REEF
re_g <- subset(re, re$class=="Gastropoda") # gastropods
re_bi <- subset(re, re$class=="Bivalvia") # bivalves
re_br <- subset(re, re$phylum=="Brachiopoda") # brachiopods
## stats
dd_re <-divDyn(re, tax="clgen", bin="stg") # entire reef dataset
dd_re_g <-divDyn(re_g, tax="clgen", bin="stg") # gastropods
dd_re_bi <-divDyn(re_bi, tax="clgen", bin="stg") # bivalves
dd_re_br <-divDyn(re_br, tax="clgen", bin="stg") # brachiopods

##plot genus richness of reef dataset # appendix 7B
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylab="genus richness (CSIB)", ylim=c(0,250))
lines(stages$mid[35:50], dd_re$divCSIB[35:50], col=cols[4], lwd=2) #all
lines(stages$mid[35:50], dd_re_g$divCSIB[35:50], lty=3, lwd=2, col=cols[1]) #gastropods
lines(stages$mid[35:50], dd_re_bi$divCSIB[35:50],lty=2,  lwd=2, col=cols[2]) #bivalves
lines(stages$mid[35:50], dd_re_br$divCSIB[35:50], lty=4, lwd=2, col=cols[3]) #brachiopods
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames, col=cols, lwd=c(2,2), lty=c(3,2,4,1), bg="white", inset=c(0.01, 0.01))


## divide subsetted environment datasets into taxa #NON-REEF
nr_g <- subset(nr, nr$class=="Gastropoda") # gastropods
nr_bi <- subset(nr, nr$class=="Bivalvia") # bivalves
nr_br <- subset(nr, nr$phylum=="Brachiopoda") # brachiopods
## stats
dd_nr <-divDyn(nr, tax="clgen", bin="stg") # entire non-reef dataset
dd_nr_g <-divDyn(nr_g, tax="clgen", bin="stg") # gastropods
dd_nr_bi <-divDyn(nr_bi, tax="clgen", bin="stg") # bivalves
dd_nr_br <-divDyn(nr_br, tax="clgen", bin="stg") # brachiopods


##plot genus richness of non-reef dataset # appendix 7D
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylab="genus richness (CSIB)", ylim=c(0,250))
lines(stages$mid[35:50], dd_nr$divCSIB[35:50], col=cols[4], lwd=2) #all
lines(stages$mid[35:50], dd_nr_g$divCSIB[35:50], lty=3, lwd=2, col=cols[1]) #gastropods
lines(stages$mid[35:50], dd_nr_bi$divCSIB[35:50], lty=2, lwd=2, col=cols[2]) #bivalves
lines(stages$mid[35:50], dd_nr_br$divCSIB[35:50], lty=4, lwd=2, col=cols[3]) #brachiopods
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames, col=cols, lty=c(3,2,4,1), lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

##stats for table 1
# number of genera
genera(re) # all reef
genera(re_g) # reef # gastropods
genera(re_bi) # reef # bivalves
genera(re_br) # reef # brachiopods
genera(nr) # all non-reef
genera(nr_g) # non-reef # gastropods
genera(nr_bi) # non-reef # bivalves
genera(nr_br) # non-reef # brachiopods

## divide subsetted environment datasets into taxa #SHALLOW
shal_g <- subset(shal, shal$class=="Gastropoda") # gastropods
shal_bi <- subset(shal, shal$class=="Bivalvia") # bivalves
shal_br <- subset(shal, shal$phylum=="Brachiopoda") # brachiopods
## stats
dd_shal <-divDyn(shal, tax="clgen", bin="stg") # entire shallow dataset
dd_shal_g <-divDyn(shal_g, tax="clgen", bin="stg") # gastropods
dd_shal_bi <-divDyn(shal_bi, tax="clgen", bin="stg") # bivalves
dd_shal_br <-divDyn(shal_br, tax="clgen", bin="stg") # brachiopods

##plot genus richness of shallow dataset # appendix 7E
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylab="genus richness (CSIB)", ylim=c(0,250))
lines(stages$mid[35:50], dd_shal$divCSIB[35:50], col=cols[4], lwd=2) #all
lines(stages$mid[35:50], dd_shal_g$divCSIB[35:50], lty=3, lwd=2, col=cols[1]) #gastropods
lines(stages$mid[35:50], dd_shal_bi$divCSIB[35:50],  lty=2, lwd=2, col=cols[2]) #bivalves
lines(stages$mid[35:50], dd_shal_br$divCSIB[35:50], lty=4, lwd=2, col=cols[3]) #brachiopods
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames, col=cols, lty=c(3,2,4,1), lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

## divide subsetted environment datasets into taxa #DEEP
deep_g <- subset(deep, deep$class=="Gastropoda") # gastropods
deep_bi <- subset(deep, deep$class=="Bivalvia") # bivalves
deep_br <- subset(deep, deep$phylum=="Brachiopoda") # brachiopods
## stats
dd_deep <-divDyn(deep, tax="clgen", bin="stg") # entire deep dataset
dd_deep_g <-divDyn(deep_g, tax="clgen", bin="stg") # gastropods
dd_deep_bi <-divDyn(deep_bi, tax="clgen", bin="stg") # bivalves
dd_deep_br <-divDyn(deep_br, tax="clgen", bin="stg") # brachiopods

##plot genus richness of deep dataset # appendix 7G
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylab="genus richness (CSIB)", ylim=c(0,250))
lines(stages$mid[35:50], dd_deep$divCSIB[35:50], col=cols[4], lwd=2) #all
lines(stages$mid[35:50], dd_deep_g$divCSIB[35:50], lty=3, lwd=2, col=cols[1]) #gastropods
lines(stages$mid[35:50], dd_deep_bi$divCSIB[35:50], lty=2, lwd=2, col=cols[2]) #bivalves
lines(stages$mid[35:50], dd_deep_br$divCSIB[35:50], lty=4, lwd=2, col=cols[3]) #brachiopods
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames, col=cols, lty=c(3,2,4,1), lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

##stats for table 1
# number of genera
genera(shal) # all shallow
genera(shal_g) # shallow # gastropods
genera(shal_bi) # shallow # bivalves
genera(shal_br) # shallow # brachiopods
genera(deep) # all deep
genera(deep_g) # deep # gastropods
genera(deep_bi) # deep # bivalves
genera(deep_br) # deep # brachiopods

## divide subsetted environment datasets into taxa #FINE
fine_g <- subset(fine, fine$class=="Gastropoda") # gastropods
fine_bi <- subset(fine, fine$class=="Bivalvia") # bivalves
fine_br <- subset(fine, fine$phylum=="Brachiopoda") # brachiopods
## stats
dd_fine <-divDyn(fine, tax="clgen", bin="stg") # entire fine dataset
dd_fine_g <-divDyn(fine_g, tax="clgen", bin="stg") # gastropods
dd_fine_bi <-divDyn(fine_bi, tax="clgen", bin="stg") # bivalves
dd_fine_br <-divDyn(fine_br, tax="clgen", bin="stg") # brachiopods

##plot genus richness of fine dataset # appendix 7F
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylab="genus richness (CSIB)", ylim=c(0,250))
lines(stages$mid[35:50], dd_fine$divCSIB[35:50], col=cols[4], lwd=2) #all
lines(stages$mid[35:50], dd_fine_g$divCSIB[35:50], lty=3, lwd=2, col=cols[1]) #gastropods
lines(stages$mid[35:50], dd_fine_bi$divCSIB[35:50], lty=2, lwd=2, col=cols[2]) #bivalves
lines(stages$mid[35:50], dd_fine_br$divCSIB[35:50], lty=4, lwd=2, col=cols[3]) #brachiopods
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames, col=cols, lty=c(3,2,4,1), lwd=c(2,2), bg="white", inset=c(0.01, 0.01))


## divide subsetted environment datasets into taxa #COARSE
co_g <- subset(co, co$class=="Gastropoda") # gastropods
co_bi <- subset(co, co$class=="Bivalvia") # bivalves
co_br <- subset(co, co$phylum=="Brachiopoda") # brachiopods
## stats
dd_co <-divDyn(co, tax="clgen", bin="stg") # entire coarse dataset
dd_co_g <-divDyn(co_g, tax="clgen", bin="stg") # gastropods
dd_co_bi <-divDyn(co_bi, tax="clgen", bin="stg") # bivalves
dd_co_br <-divDyn(co_br, tax="clgen", bin="stg") # brachiopods

##plot genus richness of coarse dataset # appendix 7H
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylab="genus richness (CSIB)", ylim=c(0,250))
lines(stages$mid[35:50], dd_co$divCSIB[35:50], col=cols[4], lwd=2) #all
lines(stages$mid[35:50], dd_co_g$divCSIB[35:50], lty=3, lwd=2, col=cols[1]) #gastropods
lines(stages$mid[35:50], dd_co_bi$divCSIB[35:50], lty=2, lwd=2, col=cols[2]) #bivalves
lines(stages$mid[35:50], dd_co_br$divCSIB[35:50], lty=4, lwd=2, col=cols[3]) #brachiopods
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames, col=cols, lty=c(3,2,4,1), lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

##stats for table 1
# number of genera
genera(fine) # all fine
genera(fine_g) # fine # gastropods
genera(fine_bi) # fine # bivalves
genera(fine_br) # fine # brachiopods
genera(co) # all coarse
genera(co_g) # coarse # gastropods
genera(co_bi) # coarse # bivalves
genera(co_br) # coarse # brachiopods

##analyzing taxonomic rates
##use divDyn function to calculate metrics for datasets
#entire dataset
dd <- divDyn(all, bin="stg", tax="clgen")
# only carbonates
dd_carb <- divDyn(carb, bin="stg", tax="clgen")
# only siliciclastics
dd_sil <- divDyn(sil, bin="stg", tax="clgen")
#only deep
dd_deep <- divDyn(deep, bin="stg", tax="clgen")
#only shallow
dd_shal <- divDyn(shal, bin="stg", tax="clgen")
#only coarse
dd_co <- divDyn(co, bin="stg", tax="clgen")
#only fine
dd_fine <- divDyn(fine, bin="stg", tax="clgen")
#only reef
dd_re <- divDyn(re, bin="stg", tax="clgen")
#only non-reef
dd_nr <- divDyn(nr, bin="stg", tax="clgen")

# return origination rates from datasets
ori <- dd[ , "oriPC"] # origination rates entire dataset
ori_carb <- dd_carb[ , "oriPC"] # origination rates carbonates
ori_sil <- dd_sil[ , "oriPC"] # origination rates siliciclastics
ori_deep <- dd_deep[ , "oriPC"] # origination rates deep
ori_shal <- dd_shal[ , "oriPC"] # origination rates shallow
ori_co <- dd_co[ , "oriPC"] # origination rates coarse
ori_fine <- dd_fine[ , "oriPC"] # origination rates fine
ori_re <- dd_re[ , "oriPC"] # origination rates reef
ori_nr <- dd_nr[ , "oriPC"] # origination rates non-reef

# return extinction rates from datasets
ext <- dd[ , "extPC"] # extinction rates entire dataset
ext_carb <- dd_carb[ , "extPC"] # extinction rates carbonates
ext_sil <- dd_sil[ , "extPC"] # extinction rates siliciclastics
ext_deep <- dd_deep[ , "extPC"] # extinction rates deep
ext_shal <- dd_shal[ , "extPC"] # extinction rates shallow
ext_co <- dd_co[ , "extPC"] # extinction rates coarse
ext_fine <- dd_fine[ , "extPC"] # extinction rates fine
ext_re <- dd_re[ , "extPC"] # extinction rates reef
ext_nr <- dd_nr[ , "extPC"] # extinction rates non-reef


#plot origination rates ##appendix 8
cols2 <- c("cadetblue3","darkolivegreen3","violetred2","purple","cornflowerblue","royalblue4","orange","brown","black")
plotnames2 <- c("carbonates","siliciclastics","reef","non-reef","shallow","deep","fine","coarse","all")
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylim=c(0, 1.3), ylab="origination rates")
lines(age[35:50], ori[35:50], col=cols2[9], lty=5, lwd=2) # entire dataset
lines(age[35:50], ori_carb[35:50], lty=3, col=cols2[1], lwd=2) # carbonates
lines(age[35:50], ori_sil[35:50], col=cols2[2], lwd=2) # siliciclastics
lines(age[35:50], ori_re[35:50], col=cols2[3], lty=3, lwd=2) # reef
lines(age[35:50], ori_nr[35:50], col=cols2[4], lwd=2) # non-reef
lines(age[35:50], ori_shal[35:50], col=cols2[5], lty=3, lwd=2) # shallow
lines(age[35:50], ori_deep[35:50], col=cols2[6], lwd=2) # deep
lines(age[35:50], ori_fine[35:50], col=cols2[7], lty=3, lwd=2) # fine-grained
lines(age[35:50], ori_co[35:50], col=cols2[8], lwd=2) # coarse-grained
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames2, col=cols2, lty= c(3,1,3,1,3,1,3,1,5), lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

#plot origination rates ##appendix 9A CARBONATES + SILICICLASTICS
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylim=c(0, 1.3), ylab="origination rates")
lines(age[35:50], ori[35:50], col=cols2[9], lty=5, lwd=2) # all
lines(age[35:50], ori_carb[35:50], lty=3, col=cols2[1], lwd=2) # carbonates
lines(age[35:50], ori_sil[35:50], col=cols2[2], lwd=2) # siliciclastics
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames2, lty=c(3,1,3,1,3,1,3,1,5), col=cols2, lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

#plot origination rates ##appendix 9B SHALLOW + DEEP
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylim=c(0, 1.3), ylab="origination rates")
lines(age[35:50], ori[35:50], lty=5, col=cols2[9], lwd=2) # all
lines(age[35:50], ori_shal[35:50], lty=3, col=cols2[5], lwd=2) # shallow
lines(age[35:50], ori_deep[35:50], col=cols2[6], lwd=2) # deep
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames2, lty=c(3,1,3,1,3,1,3,1,5), col=cols2, lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

#plot origination rates ##appendix 9C FINE + COARSE
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylim=c(0, 1.3), ylab="origination rates")
lines(age[35:50], ori[35:50], lty=5, col=cols2[9], lwd=2) # all
lines(age[35:50], ori_fine[35:50], lty=3, col=cols2[7], lwd=2) # fine-grained
lines(age[35:50], ori_co[35:50], col=cols2[8], lwd=2) # coarse-grained
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames2, lty=c(3,1,3,1,3,1,3,1,5), col=cols2, lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

#plot origination rates ##appendix 9D REEF + NON-REEF
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylim=c(0, 1.3), ylab="origination rates")
lines(age[35:50], ori[35:50], col=cols2[9], lty=5, lwd=2) # all
lines(age[35:50], ori_re[35:50], lty=3, col=cols2[3], lwd=2) # reef
lines(age[35:50], ori_nr[35:50], col=cols2[4], lwd=2) # non-reef
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames2, lty=c(3,1,3,1,3,1,3,1,5), col=cols2, lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

#plot extinction rates ##appendix 10
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylim=c(0, 1.3), ylab="extinction rates")
lines(age[35:50], ext[35:50], lty=5, col=cols2[9], lwd=2) # all
lines(age[35:50], ext_carb[35:50], lty=3, col=cols2[1], lwd=2) # carbonates
lines(age[35:50], ext_sil[35:50], col=cols2[2], lwd=2) # siliciclastics
lines(age[35:50], ext_re[35:50], lty=3, col=cols2[3], lwd=2) # reef
lines(age[35:50], ext_nr[35:50], col=cols2[4], lwd=2) # non-reef
lines(age[35:50], ext_shal[35:50], lty=3, col=cols2[5], lwd=2) # shallow
lines(age[35:50], ext_deep[35:50], col=cols2[6], lwd=2) # deep
lines(age[35:50], ext_fine[35:50], lty=3, col=cols2[7], lwd=2) # fine-grained
lines(age[35:50], ext_co[35:50], col=cols2[8], lwd=2) # coarse-grained
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames2, lty=c(3,1,3,1,3,1,3,1,5), col=cols2, lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

#plot extinction rates ##appendix 11A CARBONATES + SILICICLASTICS
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylim=c(0, 1.3), ylab="extinction rates")
lines(age[35:50], ext[35:50], col=cols2[9], lty=5, lwd=2) # all
lines(age[35:50], ext_carb[35:50], col=cols2[1], lty=3, lwd=2) # carbonates
lines(age[35:50], ext_sil[35:50], col=cols2[2], lwd=2) # siliciclastics
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames2, col=cols2, lty=c(3,1,3,1,3,1,3,1,5), lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

#plot extinction rates ##appendix 11B SHALLOW + DEEP
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylim=c(0, 1.3), ylab="extinction rates")
lines(age[35:50], ext[35:50], col=cols2[9], lty=5, lwd=2) # all
lines(age[35:50], ext_shal[35:50], col=cols2[5], lty=3, lwd=2) # shallow
lines(age[35:50], ext_deep[35:50], col=cols2[6], lwd=2) # deep
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames2, col=cols2, lty=c(3,1,3,1,3,1,3,1,5),  lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

#plot extinction rates ##appendix 11C FINE + COARSE
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylim=c(0, 1.3), ylab="extinction rates")
lines(age[35:50], ext[35:50], col=cols2[9], lty=5, lwd=2) # all
lines(age[35:50], ext_fine[35:50], col=cols2[7], lty=3, lwd=2) # fine-grained
lines(age[35:50], ext_co[35:50], col=cols2[8], lwd=2) # coarse-grained
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames2, col=cols2, lty=c(3,1,3,1,3,1,3,1,5), lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

#plot extinction rates ##appendix 11D REEF + NON-REEF
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylim=c(0, 1.3), ylab="extinction rates")
lines(age[35:50], ext[35:50], col=cols2[9], lty=5, lwd=2) # all
lines(age[35:50], ext_re[35:50], col=cols2[3], lty=3, lwd=2) # reef
lines(age[35:50], ext_nr[35:50], col=cols2[4], lwd=2) # non-reef
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames2, col=cols2, lty=c(3,1,3,1,3,1,3,1,5), lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

## turnover rates by taxon
turnover <- ext+ori  #turnover for entire dataset
turnover_g <- ext_g+ori_g  #turnover rates gastropods
turnover_bi <- ext_bi+ori_bi  #turnover rates bivalves
turnover_br <- ext_br+ori_br  #turnover rates brachiopods

#plot turnover rates by taxon ## figure 2
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylim=c(0, 1.3), ylab="turnover rate")
lines(age[35:50], turnover[35:50], col=cols[4], lwd=2) #all
lines(age[35:50], turnover_g[35:50], lty=3, col=cols[1], lwd=2) #gastropods
lines(age[35:50], turnover_bi[35:50], lty=2, col=cols[2], lwd=2) #bivalves
lines(age[35:50], turnover_br[35:50], lty=4, col=cols[3], lwd=2) #brachiopods
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames, col=cols, lty=c(3,2,4,1), lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

## turnover rates by environmental affinity
turnover_carb <- ori_carb + ext_carb # turnover rates carbonates
turnover_sil <-  ori_sil + ext_sil # turnover rates siliciclastics
turnover_deep <-  ori_deep + ext_deep # turnover rates deep
turnover_shal <-  ori_shal + ext_shal # turnover rates shallow
turnover_co  <- ori_co + ext_co # turnover rates coarse
turnover_fine <-  ori_fine + ext_fine # turnover rates fine
turnover_re <-  ori_re + ext_re # turnover rates reef
turnover_nr <-  ori_nr + ext_nr # turnover rates non-reef

#plot turnover rates by environmental affinity ## fig3
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylim=c(0, 2), ylab="turnover rates")
lines(age[35:50], turnover[35:50], lty=5, col=cols2[9], lwd=2) # all
lines(age[35:50], turnover_carb[35:50], lty=3, col=cols2[1], lwd=2) # carbonates
lines(age[35:50], turnover_sil[35:50], col=cols2[2], lwd=2) # siliciclastics
lines(age[35:50], turnover_re[35:50], lty=3, col=cols2[3], lwd=2) # reef
lines(age[35:50], turnover_nr[35:50], col=cols2[4], lwd=2) # non-reef
lines(age[35:50], turnover_fine[35:50], col=cols2[7], lty=3, lwd=2) # fine-grained
lines(age[35:50], turnover_co[35:50], col=cols2[8], lwd=2) # coarse-grained
lines(age[35:50], turnover_shal[35:50], col=cols2[5], lty=3, lwd=2) # shallow
lines(age[35:50], turnover_deep[35:50], col=cols2[6], lwd=2) # deep
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames2, col=cols2, lwd=c(2,2), lty=c(3,1,3,1,3,1,3,1,5), bg="white", inset=c(0.01, 0.01))

#plot turnover rates ##appendix 12 (curves compiled manually)
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylim=c(0, 2), ylab="turnover rates")
lines(age[35:50], turnover_carb[35:50], lty=3, col=cols2[1], lwd=2) # carbonates
lines(age[35:50], turnover_sil[35:50], col=cols2[2], lwd=2) # siliciclastics
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames2[c(1,2)], col=cols2[c(1,2)], lty=c(3,1), lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylim=c(0, 2), ylab="turnover rates")
lines(age[35:50], turnover_re[35:50], col=cols2[3], lty=3, lwd=2) # reef
lines(age[35:50], turnover_nr[35:50], col=cols2[4], lwd=2) # non-reef
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames2[c(3,4)], col=cols2[c(3,4)], lty=c(3,1), lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylim=c(0, 2), ylab="turnover rates")
lines(age[35:50], turnover_shal[35:50], col=cols2[5], lty=3, lwd=2) # shallow
lines(age[35:50], turnover_deep[35:50], col=cols2[6], lwd=2) # deep
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames2[c(5,6)], col=cols2[c(5,6)], lty=c(3,1), lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylim=c(0, 2), ylab="turnover rates")
lines(age[35:50], turnover_fine[35:50], col=cols2[7], lty=3, lwd=2) # fine-grained
lines(age[35:50], turnover_co[35:50], col=cols2[8], lwd=2) # coarse-grained
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames2[c(7,8)], col=cols2[c(7,8)], lty=c(3,1), lwd=c(2,2), bg="white", inset=c(0.01, 0.01))


#######
## number of references per stage

#divide dataset into stages
k <- list()
ref <- as.numeric() #returns number of references per stage 
for (i in 1:(nrow(stages)-1)){
  
  k[[i]] <- all[all$stg==i, ]
  
  ref[i] <- length(unique(k[[i]]$reference_no))
  
}

ref <- ref[35:50] # returns number of references per stage for stages 35:50 (LPIA)

#repeat for taxa
#gastropods
g <- list()
gref <- as.numeric()
for (i in 1:(nrow(stages)-1)){
  
  g[[i]] <- gast[gast$stg==i, ]
  
  gref[i] <- length(unique(g[[i]]$reference_no))
  
}

#bivalves
bi <- list()
biref <- as.numeric()
for (i in 1:(nrow(stages)-1)){
  
  bi[[i]] <- biv[biv$stg==i, ]
  
  biref[i] <- length(unique(bi[[i]]$reference_no))
  
}

#brachiopods
br <- list()
brref <- as.numeric()
for (i in 1:(nrow(stages)-1)){
  
  br[[i]] <- brachs[brachs$stg==i, ]
  
  brref[i] <- length(unique(br[[i]]$reference_no))
  
}

# number of references per stage for stages 35:50 (LPIA)
gref <- gref[35:50] # gastropod subset
biref <- biref[35:50] # bivalve subset
brref <- brref[35:50] # brachiopod subset

props <- cbind(stages$stage[35:50],ref,gref,biref,brref) # create dataset
props <- as.data.frame(props)
props$gref.ref <- as.vector(gref/ref) # proportion of gastropod references per total references
props$biref.ref <- as.vector(biref/ref) # proportion of bivalve references per total references
props$brref.ref <- as.vector(brref/ref) # proportion of brachiopod references per total references
props # return dataframe for appendix

#plot references per stage as proportions by taxon ## appendix 16
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylim=c(0, 1), ylab="proportion of references")
lines(stages$mid[35:50], props$gref.ref, lty=3, lwd=2, col=cols[1]) #gastropods
lines(stages$mid[35:50], props$biref.ref, lty=2, lwd=2, col=cols[2]) #bivalves
lines(stages$mid[35:50], props$brref.ref, lty=4, lwd=2, col=cols[3]) #brachiopods
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames[1:3], col=cols[1:3], lty=c(3,2,4), lwd=c(2,2), bg="white", inset=c(0.01, 0.01))


#plot references per stage by taxon ## appendix 14
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylim=c(0, 280), ylab="number of references")
lines(stages$mid[35:50], ref, lwd=2, col=cols[4]) # all
lines(stages$mid[35:50], gref, lty=3, lwd=2, col=cols[1]) #gastropods
lines(stages$mid[35:50], biref, lty=2, lwd=2, col=cols[2]) #bivalves
lines(stages$mid[35:50], brref, lty=4, lwd=2, col=cols[3]) #brachiopods
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames, col=cols, lty=c(3,2,4,1), lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

## remove Clapham references
'%!in%' <- function(x,y)!('%in%'(x,y)) #make function for operator "not in"
clrefs <- read.csv(file="authorizer_clapham.csv", sep=",", header=T, skipNul = TRUE ) #load file with all references authorized by M. Clapham (previously extracted from PBDB)
clrefs <- as.vector(clrefs$x)
newall <- all[which(all$reference_no%!in%clrefs),] ##remove Clapham reference numbers from dataset

## subset new dataset
newbrachs <- subset(newall, newall$phylum=="Brachiopoda") # brachiopods
newbiv <- subset(newall, newall$class=="Bivalvia") # bivalves
newgast <- subset(newall, newall$class=="Gastropoda") # gastropods

## return number of occurrences, collections, richness and other diversity metrics in each bin per taxon
# entire dataset without Clapham entries
Snewall <- binstat(newall, tax="clgen", bin="stg", coll="collection_no", ref="reference_no", duplicates=F, indices = T, noNAStart=F)
#gastropods without Clapham entries
Snewgast <- binstat(newgast, tax="clgen", bin="stg", coll="collection_no", ref="reference_no", duplicates=F, indices = T, noNAStart=F)
#bivalves without Clapham entries
Snewbiv <- binstat(newbiv, tax="clgen", bin="stg", coll="collection_no", ref="reference_no", duplicates=F, indices = T, noNAStart=F)
#brachiopods without Clapham entries
Snewbrachs <- binstat(newbrachs, tax="clgen", bin="stg", coll="collection_no", ref="reference_no", duplicates=F, indices = T, noNAStart=F)

#plot no. of occurrences with and without Clapham entries ##appendix 17
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylim=c(0,10000), ylab="Number of occurrences")
lines(stages$mid[35:50], Sall$occs[35:50], lwd=3, col=cols[4]) #all
lines(stages$mid[35:50], Sgast$occs[35:50], lty=3, lwd=3, col=cols[1]) #gastropods
lines(stages$mid[35:50], Sbiv$occs[35:50], lty=2, lwd=3, col=cols[2]) #bivalves
lines(stages$mid[35:50], Sbrachs$occs[35:50], lty=4, lwd=3, col=cols[3]) #brachiopods
lines(stages$mid[35:50], Snewall$occs[35:50], lwd=1, col=cols[4]) #all without Clapham
lines(stages$mid[35:50], Snewgast$occs[35:50], lty=3, lwd=1, col=cols[1]) #gastropods without Clapham
lines(stages$mid[35:50], Snewbiv$occs[35:50], lty=2, lwd=1, col=cols[2]) #bivalves without Clapham
lines(stages$mid[35:50], Snewbrachs$occs[35:50], lty=4, lwd=1, col=cols[3]) #brachiopods without Clapham
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames, col=cols, lty=c(3,2,4,1), lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

##use divDyn function to calculate metrics for datasets
#entire dataset without Clapham
new_dd <- divDyn(newall, bin="stg", tax="clgen")
# gastropods
newdd_g<- divDyn(newgast, bin="stg", tax="clgen")
# bivalves
newdd_bi<- divDyn(newbiv, bin="stg", tax="clgen")
# brachiopods
newdd_br<- divDyn(newbrachs, bin="stg", tax="clgen")

#plot genus richness (CSIB) ##appendix 18 
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylab="genus richness (CSIB)", ylim=c(0,1000))
lines(stages$mid[35:50], dd$divCSIB[35:50], col=cols[4], lwd=3) #all
lines(stages$mid[35:50], dd_g$divCSIB[35:50], lty=3, lwd=3, col=cols[1]) #gastropods
lines(stages$mid[35:50], dd_bi$divCSIB[35:50], lty=2, lwd=3, col=cols[2]) #bivalves
lines(stages$mid[35:50], dd_br$divCSIB[35:50], lty=4, lwd=3, col=cols[3]) #brachiopods
lines(stages$mid[35:50], new_dd$divCSIB[35:50], col=cols[4], lwd=1) #all without Clapham entries
lines(stages$mid[35:50], newdd_g$divCSIB[35:50], lty=3, lwd=1, col=cols[1]) #gastropods without Clapham entries
lines(stages$mid[35:50], newdd_bi$divCSIB[35:50],lty=2, lwd=1, col=cols[2]) #bivalves without Clapham entries
lines(stages$mid[35:50], newdd_br$divCSIB[35:50], lty=4, lwd=1, col=cols[3]) #brachiopods without Clapham entries
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames, col=cols, lwd=c(2,2), lty=c(3,2,4,1), bg="white", inset=c(0.01, 0.01))


##subsampling using SQS, quorum = 0.60, 500 iterations
# entire dataset without Clapham entries
newsqs0.6 <-subsample(newall, iter=500, q=0.6, tax="clgen", bin="stg", type="sqs", noNAStart=TRUE, singleton=F)
#gastropods without Clapham entries
newsqs0.6.g <-subsample(newgast, iter=500, q=0.6, tax="clgen", bin="stg", type="sqs", noNAStart=TRUE, singleton=F)
#bivalves without Clapham entries
newsqs0.6.bi <-subsample(newbiv, iter=500, q=0.6, tax="clgen", bin="stg", type="sqs", noNAStart=TRUE, singleton=F)
#brachiopods without Clapham entries
newsqs0.6.br <-subsample(newbrachs, iter=500, q=0.6, tax="clgen", bin="stg", type="sqs", noNAStart=TRUE, singleton=F)

#plot SQS genus richness (CSIB) ##appendix 19 
windows(h=8, w=14)
tsplot(stages, shading="stage", boxes="short", xlim=35:50, ylab="SQS genus richness (CSIB)", ylim=c(0,200))
lines(stages$mid[35:50], sqs0.6$divCSIB, col=cols[4], lwd=3) #all
lines(stages$mid[35:50], sqs0.6.g$divCSIB, lty=3, lwd=3, col=cols[1]) #gastropods
lines(stages$mid[35:50], sqs0.6.bi$divCSIB, lty=2, lwd=3, col=cols[2]) #bivalves
lines(stages$mid[35:50], sqs0.6.br$divCSIB, lty=4, lwd=3, col=cols[3]) #brachiopods
lines(stages$mid[35:50], newsqs0.6$divCSIB, col=cols[4], lwd=1) #all without Clapham entries
lines(stages$mid[35:50], newsqs0.6.g$divCSIB, lty=3, lwd=1, col=cols[1]) #gastropods without Clapham entries
lines(stages$mid[35:50], newsqs0.6.bi$divCSIB, lty=2, lwd=1, col=cols[2]) #bivalves without Clapham entries
lines(stages$mid[35:50], newsqs0.6.br$divCSIB, lty=4, lwd=1, col=cols[3]) #brachiopods without Clapham entries
abline(v=298.9, lwd=2)
legend("topleft", legend=plotnames, col=cols, lty=c(3,2,4,1), lwd=c(2,2), bg="white", inset=c(0.01, 0.01))

###

## correlation results Phanerozoic # appendix 15
phan <- read.csv(file="Phanerozoic.csv", sep=",", header=T, skipNul = TRUE ) # load Phanerozoic dataset
colnames(phan)

## prepare data
phan <- phan[phan$genus!="", ]  # remove non-informative genus names
phan <- subset(phan, accepted_rank=="species" | accepted_rank=="genus") # limit to entries with at least genus rank
excl <- which(duplicated(phan$occurrence_no)) # no duplicates
phan$clgen <- paste(phan$class, phan$genus)  # in case there are homonymies, add class name to genus name in new column "clgen"

## stratigraphic binning
data(stages) # load stages object from divDyn
data(keys)  # load keys object from divDyn #contains information to group occurrences based on environmental and lithological variables
stgMin <- categorize(phan[ ,"early_interval"], keys$stgInt) # categorize entries by stages according to keys object (using stage numbers)
stgMax <- categorize(phan[ ,"late_interval"], keys$stgInt) # categorize entries by stages according to keys object (using stage numbers)
stgMin <- as.numeric(stgMin) # convert stage numbers  to numeric
stgMax <- as.numeric(stgMax) # convert stage numbers  to numeric
phan$stg <- rep(NA, nrow(phan)) # create empty vector
# condition is expressed indicating which rows have only single assigned stage number:
# select entries, where
stgCondition <- c(
  # the early and late interval fields indicate the same stg
  which(stgMax==stgMin),
  # or the late_interval field is empty
  which(stgMax==-1))
# those values are copied for which the condition is true
phan$stg[stgCondition] <- stgMin[stgCondition] # in these entries, use the stg indicated by the early_interval

##stats for appendix 15
nrow(phan) # total number of occurrences
length(unique(phan$clgen)) # total number of genera

# subset dataset to entries with stage level information
phan <- phan[!is.na(phan$stg), ]  #remove entries without stage

## subset data
phan.biv <- subset(phan, phan$class=="Bivalvia") # bivalves
phan.gast <- subset(phan, phan$class=="Gastropoda") # gastropods
phan.brachs <- subset(phan, phan$phylum=="Brachiopoda") # brachiopods

### stats
## return number of occurrences, collections, richness and other diversity metrics in each bin per taxon
# entire dataset
S.phan <- binstat(phan, tax="clgen", bin="stg", coll="collection_no", ref="reference_no", duplicates=F, indices = T, noNAStart=F)
#gastropods
S.phan.gast <- binstat(phan.gast, tax="clgen", bin="stg", coll="collection_no", ref="reference_no", duplicates=F, indices = T, noNAStart=F)
#bivalves
S.phan.biv <- binstat(phan.biv, tax="clgen", bin="stg", coll="collection_no", ref="reference_no", duplicates=F, indices = T, noNAStart=F)
#brachiopods
S.phan.brachs <- binstat(phan.brachs, tax="clgen", bin="stg", coll="collection_no", ref="reference_no", duplicates=F, indices = T, noNAStart=F)


##subsampling using SQS, quorum = 0.60, 100 iterations
# entire dataset
phan.sqs0.6 <-subsample(phan, iter=100, q=0.6, tax="clgen", bin="stg", type="sqs", noNAStart=TRUE, singleton=F)
#gastropods
phan.sqs0.6.g <-subsample(phan.gast, iter=100, q=0.6, tax="clgen", bin="stg", type="sqs", noNAStart=TRUE, singleton=F)
#bivalves
phan.sqs0.6.bi <-subsample(phan.biv, iter=100, q=0.6, tax="clgen", bin="stg", type="sqs", noNAStart=TRUE, singleton=F)
#brachiopods
phan.sqs0.6.br <-subsample(phan.brachs, iter=100, q=0.6, tax="clgen", bin="stg", type="sqs", noNAStart=TRUE, singleton=F)

# (1) Number occurrences/references per stage
cor.test(S.phan$occs, S.phan$refs, method="spearman") #phanerozoic # all
cor.test(S.phan.gast$occs, S.phan.gast$refs, method="spearman") #phanerozoic # gastropods
cor.test(S.phan.biv$occs, S.phan.biv$refs, method="spearman") #phanerozoic # bivalves
cor.test(S.phan.brachs$occs, S.phan.brachs$refs, method="spearman") #phaenrozoic # brachiopods

# (2) Genus richness/number of references per stage
cor.test(S.phan$richness, S.phan$refs, method="spearman") #phanerozoic # all
cor.test(S.phan.gast$richness, S.phan.gast$refs, method="spearman") #phanerozoic # gastropods
cor.test(S.phan.biv$richness, S.phan.biv$refs, method="spearman") #phanerozoic # bivalves
cor.test(S.phan.brachs$richness, S.phan.brachs$refs, method="spearman") #phanerozoic # brachiopods

# (3) Subsampled (SQS) genus richness
cor.test(phan.sqs0.6$divSIB, S.phan$refs[14:95], method="spearman") #phanerozoic # all
cor.test(phan.sqs0.6.g$divSIB, S.phan.gast$refs[14:95], method="spearman") #phanerozoic # gastropods
cor.test(phan.sqs0.6.bi$divSIB, S.phan.biv$refs[14:95], method="spearman") #phanerozoic # bivalves
cor.test(phan.sqs0.6.br$divSIB, S.phan.brachs$refs[14:95], method="spearman") #phanerozoic # brachiopods

## correlation results LPIA 
# (1) Number occurrences/references per stage
cor.test(Sall$occs, Sall$refs, method="spearman") #phanerozoic # all
cor.test(Sgast$occs, Sgast$refs, method="spearman") #phanerozoic # gastropods
cor.test(Sbiv$occs, Sbiv$refs, method="spearman") #phanerozoic # bivalves
cor.test(Sbrachs$occs, Sbrachs$refs, method="spearman") #phaenrozoic # brachiopods

# (2) Genus richness/number of references per stage
cor.test(Sall$richness, Sall$refs, method="spearman") #phanerozoic # all
cor.test(Sgast$richness, Sgast$refs, method="spearman") #phanerozoic # gastropods
cor.test(Sbiv$richness, Sbiv$refs, method="spearman") #phanerozoic # bivalves
cor.test(Sbrachs$richness, Sbrachs$refs, method="spearman") #phanerozoic # brachiopods

# (3) Subsampled (SQS) genus richness
cor.test(sqs0.6$divSIB, Sall$refs[35:50], method="spearman") #phanerozoic # all
cor.test(sqs0.6.g$divSIB, Sgast$refs[35:50], method="spearman") #phanerozoic # gastropods
cor.test(sqs0.6.bi$divSIB, Sbiv$refs[35:50], method="spearman") #phanerozoic # bivalves
cor.test(sqs0.6.br$divSIB, Sbrachs$refs[35:50], method="spearman") #phanerozoic # brachiopods

####
###
##count occurrences with complete dataset (incl. entries without stage information) # table 1
keys$lith2 <- lith_new # might be necessary to rerun this line of code
all2$lith2 <- categorize(all2$lithology1, keys$lith2) # categorize lithology into assigned groups using complete dataset "all2"
table(all2$lith2) # occurrences lithology
all2$bath <- categorize(all2$environment, keys$bath) # categorize water depth
table(all2$bath) # occurrences water depth
all2$gra <- categorize(all2$lithology1, keys$grain) # categorize grainsize
table(all2$gra) # occurrences grainsize
all2$reef <- categorize(all2$environment, keys$reef) # categorize environment type (reef vs. non-reef)
table(all2$reef) # occurrences reef/non-reef
#count occurrences of subsets
nrow(subset(all2, class=="Bivalvia" & lith2=="carbonate"))
nrow(subset(all2, class=="Gastropoda" & lith2=="carbonate"))
nrow(subset(all2, phylum=="Brachiopoda" & lith2=="carbonate"))
nrow(subset(all2, class=="Bivalvia" & lith2=="siliciclastics"))
nrow(subset(all2, class=="Gastropoda" & lith2=="siliciclastics"))
nrow(subset(all2, phylum=="Brachiopoda" & lith2=="siliciclastics"))
nrow(subset(all2, class=="Bivalvia" & bath=="deep"))
nrow(subset(all2, class=="Gastropoda" & bath=="deep"))
nrow(subset(all2, phylum=="Brachiopoda" & bath=="deep"))
nrow(subset(all2, class=="Bivalvia" & bath=="shallow"))
nrow(subset(all2, class=="Gastropoda" & bath=="shallow"))
nrow(subset(all2, phylum=="Brachiopoda" & bath=="shallow"))
nrow(subset(all2, class=="Bivalvia" & gra=="fine"))
nrow(subset(all2, class=="Gastropoda" & gra=="fine"))
nrow(subset(all2, phylum=="Brachiopoda" & gra=="fine"))
nrow(subset(all2, class=="Bivalvia" & gra=="coarse"))
nrow(subset(all2, class=="Gastropoda" & gra=="coarse"))
nrow(subset(all2, phylum=="Brachiopoda" & gra=="coarse"))
nrow(subset(all2, class=="Bivalvia" & reef=="reef"))
nrow(subset(all2, class=="Gastropoda" & reef=="reef"))
nrow(subset(all2, phylum=="Brachiopoda" & reef=="reef"))
nrow(subset(all2, class=="Bivalvia" & reef=="non-reef"))
nrow(subset(all2, class=="Gastropoda" & reef=="non-reef"))
nrow(subset(all2, phylum=="Brachiopoda" & reef=="non-reef"))
     
